OC.L10N.register(
    "settings",
    {
    "Private" : "Priváu",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Namás ye visible pa les persones que concasen pela integración del númberu de teléfonu pente Talk en móviles",
    "Local" : "Llocal",
    "Only visible to people on this instance and guests" : "Namás ye visible pa les persones d'esta instancia y los convidaos",
    "Federated" : "Federada",
    "Only synchronize to trusted servers" : "Namás sincronizar con sirvidores d'enfotu",
    "Published" : "Espublizóse",
    "Synchronize to trusted servers and the global and public address book" : "Sincroniza con sirvidores d'enfotu y la llibreta de direiciones global y pública",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando…",
    "Unable to change password" : "Nun ye posible camudar la contraseña",
    "Very weak password" : "La contraseña ye mui poco segura",
    "Weak password" : "La contraseña ye poco segura",
    "So-so password" : "La contraseña ye normal",
    "Good password" : "La contraseña ye segura",
    "Strong password" : "La contraseña ye mui segura",
    "Groups" : "Grupos",
    "Group list is empty" : "La llista de grupos ta balera",
    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
    "{actor} added you to group {group}" : "{actor} metióte nel grupu «{group}»",
    "You added {user} to group {group}" : "Metiesti a {user} nel grupu «{group}»",
    "{actor} added {user} to group {group}" : "{actor} metió a {user} nel grupu «{group}»",
    "An administrator added you to group {group}" : "L'alministración metióte nel grupu «{group}»",
    "An administrator added {user} to group {group}" : "L'alministrador metió a {user} nel grupu «{group}»",
    "{actor} removed you from group {group}" : "{actor} quitóte del grupu «{group}»",
    "You removed {user} from group {group}" : "Quitesti a {user} del grupu «{group}»",
    "{actor} removed {user} from group {group}" : "{actor} quitó a {user} del grupu «{group}»",
    "An administrator removed you from group {group}" : "L'alministración quitóte del grupu «{group}»",
    "An administrator removed {user} from group {group}" : "L'alministración quitó a {user} del grupu «{group}»",
    "Your <strong>group memberships</strong> were modified" : "Modificáronse la <strong>pertenencia a los grupos</strong>",
    "{actor} changed your password" : "{actor} camudó la contraseña",
    "You changed your password" : "Camudesti la contraseña",
    "Your password was reset by an administrator" : "L'alministración reanició la to contraseña",
    "Your password was reset" : "Reanicióse la contraseña",
    "{actor} changed your email address" : "{actor} camudó la to direición de corréu electróncu",
    "You changed your email address" : "Camudesti la direición de corréu electrónicu",
    "Your email address was changed by an administrator" : "L'alministración camudó la to direición de corréu electrónicu",
    "You created an app password for a session named \"{token}\"" : "Creesti una contraseña d'aplicación pa una sesión nomada «{token}»",
    "An administrator created an app password for a session named \"{token}\"" : "L'alministración creó una contraseña d'aplicación pa una sesión nomada «{token}»",
    "You deleted app password \"{token}\"" : "Desaniciesti la contraseña d'aplicación «{token}»",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Renomóse la contraseña d'aplicación «{token}» a «{newToken}»",
    "You granted filesystem access to app password \"{token}\"" : "Concediesti l'accesu al sistema de ficheros pa la contraseña d'aplicación «{token}»",
    "You revoked filesystem access from app password \"{token}\"" : "Revoquesti l'accesu al sistema de ficheros pa la contraseña d'aplicación «{token}»",
    "Security" : "Seguranza",
    "You successfully logged in using two-factor authentication (%1$s)" : "Aniciesti la sesión correutamente cola autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Fízose un intentu d'aniciar la sesión cola autenticación en dos pasos que falló (%1$s)",
    "Remote wipe was started on %1$s" : "Anicióse'l borráu remotu'l %1$s",
    "Remote wipe has finished on %1$s" : "El borráu remotu finó'l %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Modificóse la <strong>contraseña</strong> o la <strong>direición de corréu electrónicu</strong>",
    "Settings" : "Configuración",
    "Could not remove app." : "Nun se pudo quitar l'aplicación.",
    "Could not update app." : "Nun se pudo anovar l'aplicación",
    "Wrong password" : "La contraseña ye incorreuta",
    "Unable to change personal password" : "Nun ye posible camudar la contraseña personal",
    "Saved" : "Guardóse",
    "No Login supplied" : "Nun se fornió nenguna cuenta",
    "Unable to change password. Password too long." : "Nun ye posible camudar la contraseña, ye mui llonga.",
    "Authentication error" : "Error de l'autenticación",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Forni una contraseña de recuperación de l'alministración; d'otra miente, van perdese colos datos de la cuenta",
    "Wrong admin recovery password. Please check the password and try again." : "La contraseña de recuperación de l'alministración ye incorreuta. Compruébala y volvi tentalo.",
    "Backend does not support password change, but the encryption of the account key was updated." : "El backend nun ye compatible col cambéu de contraseña, mas anovóse'l cifráu de la clave de la cuenta.",
    "Administrator documentation" : "Documentación p'alministradores",
    "User documentation" : "Documentación pa usuarios",
    "Nextcloud help overview" : "Vista xeneral de l'ayuda de Nextcloud",
    "Invalid SMTP password." : "La contraseña SMTP ye incorreuta.",
    "Email setting test" : "Prueba de la configuración de corréu electrónicu",
    "Well done, %s!" : "Bien fecho, ¡%s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibiesti esti mensaxe, la configuración de corréu electrónicu paez ser correuta.",
    "Email could not be sent. Check your mail server log" : "Nun se pudo unviar el mensaxe. Comprueba'l rexistru del sirvidor de corréu.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Prodúxose un problema mentanto s'unviaba'l mensaxe. Revisa la configuración. (error: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Tienes d'afitar la direición de corréu electrónicu de la cuenta enantes de comenzar a unviar mensaxe de prueba. Vete a %s pa facelo.",
    "Disabled accounts" : "Cuentes desactivaes",
    "Invalid account" : "Cuenta non válida",
    "Invalid mail address" : "La direición de corréu electrónicu ye incorreuta",
    "Settings saved" : "Guardóse la configuración",
    "Unable to change full name" : "Nun ye posible camudar el nome completu",
    "Unable to change email address" : "Nun ye posible camudar la direición de corréu electrónicu",
    "Unable to set invalid phone number" : "Nun ye posible afitar un númberu de teléfonu inválidu",
    "Unable to set invalid website" : "Nun ye posible afitar un sitiu web inválidu",
    "Some account data was invalid" : "Dalgunos datos de la cuenta son inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pa verificar la to cuenta de Twitter, espubliza'l tweet siguiente (asegúrate d'espublizalu ensin nengún saltu de llinia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pa verificar el sitiu web, atroxa'l conteníu siguiente nel so raigañu en «.well-known/CloudIdVerificationCode.txt» (asegúrate de que'l testu ta nuna única llinia):",
    "%1$s changed your password on %2$s." : "%1$s camudó la contraseña de: %2$s.",
    "Your password on %s was changed." : "La to contraseña de «%s» camudó.",
    "Your password on %s was reset by an administrator." : "L'alministración reanició la to contraseña de: %s.",
    "Your password on %s was reset." : "Reanicióse la to contraseña de: %s.",
    "Password for %1$s changed on %2$s" : "La contraseña pa «%1$s» camudó en «%2$s»",
    "Password changed for %s" : "La contraseña camudó pa: %s",
    "If you did not request this, please contact an administrator." : "Si nun solicitesti esta aición, ponte en contautu cola alministración.",
    "Your email address on %s was changed." : "La to direición de corréu electrónicu de %s camudó.",
    "Your email address on %s was changed by an administrator." : "L'alministración camudó la to direición de corréu electrónicu de %s",
    "Email address for %1$s changed on %2$s" : "La direición de corréu electrónciu pa %1$s camudó en %2$s",
    "Email address changed for %s" : "La direición de corréu electrónicu camudó pa %s",
    "The new email address is %s" : "La direición de corréu electrónicu nueva ye %s",
    "Your %s account was created" : "Creóse la cuenta %s",
    "Welcome aboard" : "Afáyate",
    "Welcome aboard %s" : "Afáyate, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Afáyate na cuenta %s, pues editar, protexer y compartir los tos datos.",
    "Your Login is: %s" : "La to cuenta ye: %s",
    "Set your password" : "Afitar la contraseña",
    "Go to %s" : "Dir a «%s»",
    "Install Client" : "Instalar el veceru",
    "Apps" : "Aplicaciones",
    "Personal" : "Personal",
    "Administration" : "Alministración",
    "Users" : "Usuarios",
    "Additional settings" : "Configuración adicional",
    "Assistant" : "Asistente",
    "Administration privileges" : "Privilexos de l'alministración",
    "Groupware" : "Trabayu en grupu",
    "Overview" : "Vista xeneral",
    "Basic settings" : "Configuración básica",
    "Sharing" : "Compartición",
    "Availability" : "Disponibilidá",
    "Calendar" : "Calendariu",
    "Personal info" : "Información personal",
    "Mobile & desktop" : "Móvil y ordenador",
    "Artificial Intelligence" : "Intelixencia artificial",
    "Email server" : "Sirvidor de corréu electrónicu",
    "Background jobs" : "Trabayos en segundu planu",
    "Unlimited" : "Ensin llende",
    "Verifying" : "Verificando",
    "App directories owner" : "Propietariu de los direutorios d'aplicación",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Dalgunos direutorios d'aplicación son propiedá d'otru usuariu y non del usuariu del sirvidor web. Esto pue pasar si dalgunes aplicaciones d'instalaron manualmente. Comprueba los permisos de los direutorios d'aplicación siguientes:\n%s",
    "App directories have the correct owner \"%s\"" : "Los direutorios d'aplicación tienen el propietariu correutu «%s»",
    "Brute-force Throttle" : "Llende de la fuercia bruta",
    "Your remote address could not be determined." : "Nun se pudo determinar la direición remota.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "La direición remota identificóse como «%s» y nesti momentu ta llendada per fuercia bruta, cosa qu'amenorga'l rendimientu de delles solicitúes. Si la direición remota nun ye la to direición, pue ser un indicador de qu'un proxy nun ta configuráu correutamente.",
    "Your remote address \"%s\" is not brute-force throttled." : "La direición remota «%s» nun ta llendada per fuercia bruta.",
    "Old administration imported certificates" : "Certificaos importaos de l'alministración antigua",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Hai un trabayu en segundu planu pendiente que comprueba los certificaos SSL importaos de l'alministración. Volvi equí dempués.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hai presentes dalgunos certificaos SSL importaos de l'alministración que yá nun s'usen en Nextcloud 21. Pues importalos na llinia de comandos pel comandu «occ security:certificates:import». Abaxo amúesense los sos caminos dientro del direutoriu de datos.",
    "Code integrity" : "Integridá del códigu",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Desactivóse'l comprobador de la integridá. Nun se pue verificar la integridá.",
    "No altered files" : "Nun hai nengún ficheru alteriáu",
    "Some files have not passed the integrity check. {link1} {link2}" : "Dalgunos ficheros nun pasaron la comprobación de la integridá. {link1} {link2}",
    "Cron errors" : "Errores de cron",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Nun foi posible executar el trabayu de cron per CLI. Apaecieron los errores téunicos siguientes:\n%s",
    "The last cron job ran without errors." : "L'últimu trabayu de cron executóse ensin errores.",
    "Cron last run" : "Última execución de cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "La última execución del trabayu en segundu planu executó %s. Paez qu'hai daqué mal. {link}.",
    "Last background job execution ran %s." : "La última execución del trabayu en segundu planu executó %s.",
    "Data directory protected" : "Direutoriu de datos protexíu",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet. El ficheru .httaccess nun funciona. Ye mui aconseyable que configures el sirvidor web pa que yá nun se pueda acceder al direutoriu de datos o movi los datos del direutoriu fuera del raigañu de documentos del sirvidor web.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nun se pudo comprobar que'l direutoriu de datos tea protexíu. Comprueba manualmente que'l sirvidor nun permite l'accesu al direutoriu de datos.",
    "Database missing columns" : "Columnes faltantes de la base de datos",
    "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opciones «%s» de la tabla «%s.»",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos fálten-y columnes opcionales. Como amestar columnes a table grandes pue tardar tiempu y son opcionales, nun s'amestaron automáticamente. Pues executar «occ db:add-missing-columns» p'amestar les columnes que falten manualmente cola instancia en funcionamientu. Dempués d'amestar la columnes, ye posible qu'ameyora'l tiempu de rempuesta o la usabilidá de dalgunes funciones.",
    "Database missing indices" : "Índices faltantes na base de datos",
    "Database missing primary keys" : "Claves primaries faltantes na base de datos",
    "Missing primary key on table \"%s\"." : "Falta la clave primaria na tabal «%s».",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos fálten-y dalgunes claves primaries. Pola mor de qu'amestar claves primaries en tables grandes pue tardar tiempu, nun s'amestaron automáticamente. Al executar «occ db:add-missing-primary-keys» eses claves primaries que falten podríen amestase manualmente mentanto la instancia sigue n'execución.",
    "Database pending bigint migrations" : "Base de datos pendientes de migraciones biginit",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "A dalgunes columnes de la base de datos fálta-yos una conversión a bigint. Como'l cambéu de tipos de columna sobre tables grandes pue tardar tiempu, nun camudaron automáticamente. Al executar «occ db:convert-filecache-bigint» esos cambeos pendientes podríen aplicase manualmente. Esta operación tien de facese mentanto la instancia ta nel mou desconectáu",
    "Debug mode" : "Mou de depuración",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia execútase nel mou depuración. Activa esta opción namás pa desendolcar y non pa entornos de desendolcu.",
    "Debug mode is disabled." : "El mou de puración ta desactiváu.",
    "Default phone region" : "Rexón telefónica predeterminada",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "La instalación nun tien nenguna rexón telefónica por defeutu configurada. Ye obligatorio pa validar númberos de teléfonu ensin un códigu de país na configuración de los perfiles. Pa permitir los númberos ensin códigu de país, amiesta la opción «default_phone_region» col códigu ISO 3166-1 respeutivu de la rexón nel ficheru de configuración.",
    "Email test" : "Unviar un corréu electrónicu de prueba",
    "Email test was successfully sent" : "El corréu de prueba unvióse correutamente",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Nun afitesti o verifiquesti la configuración del sirvidor de corréu electrónicu. Vete a la «Basic settings» p'afitala. Dempués, usa'l botón «Unviar un corréu electrónicul» d'embaxo'l formulariu pa verificar la configuración",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "La base de datos úsase pal bloquéu de ficheros transaicional. P'ameyorar el rindimientu, configura la memoria caché, si ta disponible.",
    "Forwarded for headers" : "Reunvióse pa les testeres",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "La opciòn «trusted_proxies» nun s'afitó correutamente, habría ser una matriz.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "La opciòn «trusted_proxies» nun s'afitó correutamente, habría ser una matriz de direiciones IP (opcionalmente, con rangu n'anotación CIDR).",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la testera del proxy inversu ye incorreuta. Esto ye un problema de seguranza y pue permitir qu'un atacador falsie la direición IP como visible pa Nexrcloud.",
    "Your IP address was resolved as %s" : "La to direición IP resolvióse como %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la testera del proxy inversu ye incorreuta o tás accediendo a Nextcloud dende un proxy d'enfotu. Si non, esto ye un problema de seguranza y pue permitir qu'un atacador falsie la so direición IP como visible a Nextlcloud.",
    "HTTPS access and URLs" : "Acceus de HTTPS y URLs",
    "Internet connectivity" : "Conectividá a internet",
    "Internet connectivity is disabled in configuration file." : "La conectividá a internet ta desactivada nel ficheru de configuración.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Esti sirvidor nun tien una conexón a internet que funcione. Nun se pudieron algamar múltiples estremos. Esto significa que dalgunes funciones como'l montase d'almacenamientos esternos, los avisos tocante a anovamientos o la instalación d'aplicaciones de terceros nun van funcionar. L'accesu remotu a los ficheros y l'unviu de mensaxe d'avisu per corréu electrónicu puen nun funcionar tampoco. Afita una conexón d'esti sirvidor a internet pa esfrutar de toles funciones.",
    "Old server-side-encryption" : "Cifráu antiguu del sirvidor",
    "Disabled" : "Desactivóse",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "El formatu antiguu de cifráu del sirvidor ta activáu. Aconseyámoste desactivar esta función.",
    "You are not using MySQL" : "Nun tas usando MySQL",
    "PHP default charset" : "Conxuntu de carátueres predetermináu de PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "La opción de configuración PHP «default_charset» habría ser UTF-8",
    "The function is available." : "La función ta disponible.",
    "Supported" : "Compatible",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paez que PHP nun ta configuráu afayadizamente pa solicitar les variables d'entornu del sistema. La prueba con getenv(\"PATH\") namás devuelve una rempuesta balera.",
    "PHP memory limit" : "Llende de memoria de PHP",
    "PHP modules" : "Módulos de PHP",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "A esta instancia fálten-y dalgunos módulos aconseyaos de PHP. P'ameyorar el rindimientu y la compatibilidá, ye mui aconseyable que los instales:\n%s",
    "PHP opcache" : "opcache de PHP",
    "PHP version" : "Versión de PHP",
    "You are currently running PHP %s." : "Tas executando PHP %s.",
    "Random generator" : "Xenerador aleatoriu",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Activóse la configuración de namás llectura. Esta aición impide que se puedan configurar dalgunes opciones pela interfaz web. Arriendes d'eso, en cada anovamientu ye necesario activar la escritura del ficheru manualmente.",
    "Nextcloud configuration file is writable" : "El ficheru de configuración de Nextcloud ye d'escritura",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Nun se pudo comprobar que'l sirvidor web sirva les testeres de seguranza correutamente. Compruébalo manualmente.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Nun se pudo comprobar que'l sirvidor web sirva les testeres de seguranza correutamente. Nun ye posible solicitar «%s»",
    "Your server is correctly configured to send security headers." : "El sirvidor ta configuráu correutamente pa unviar testeres de seguranza.",
    "Database version" : "Versión de la base de datos",
    "Architecture" : "Arquiteutura",
    "64-bit" : "64 bits",
    "Temporary space available" : "Espaciu temporal disponible",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La base de datos nun s'executa col nivel d'aislamientu de transaiciones «READ COMMITTED». Esta transaición pue causar problemes cuando s'executen múltiples aiciones en paralelo.",
    "Profile information" : "Información del perfil",
    "Nextcloud settings" : "Configuración de Nextcloud",
    "Enable" : "Activar",
    "Machine translation" : "Traducción per ordenador",
    "Image generation" : "Xeneración d'imáxenes",
    "Text processing" : "Procesamientu de testos",
    "Task:" : "Xera:",
    "Here you can decide which group can access certain sections of the administration settings." : "Equí pues decidir qué grupu pue acceder a ciertes seiciones de la configuración d'alministración.",
    "Unable to modify setting" : "Nun ye posible modificar la opción",
    "None" : "Nada",
    "Allow apps to use the Share API" : "Permitir que les aplicaciones usen l'API de compartición",
    "Allow sharing with groups" : "Permitir la compartición colos grupos",
    "Allow users to share via link and emails" : "Permitir que los usuarios compartan per enllaz y correos electrónicos",
    "Allow public uploads" : "Permitir les xubes públiques",
    "Enforce password protection" : "Obligar la proteición de les contraseñes",
    "Two-Factor Authentication" : "Autenticación en dos pasos",
    "Enforced groups" : "Grupos obligatorios",
    "Two-factor authentication is not enforced for members of the following groups." : "L'autenticación en dos pasos nun ye obligatoria pa los miembros de los grupos siguientes.",
    "Excluded groups" : "Grupos escluyíos",
    "Save changes" : "Guardar los cambeos",
    "Default" : "Por defeutu",
    "Remove" : "Quitar",
    "Featured" : "Destacada",
    "Disable all" : "Desactivar too",
    "All apps are up-to-date." : "Toles aplicaciones tán anovaes",
    "Icon" : "Iconu",
    "Name" : "Nome",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Aiciones",
    "Results from other categories" : "Resultaos d'otres categoríes",
    "No apps found for your version" : "Nun s'atopó nenguna aplicación pa esta versión",
    "_Update_::_Update all_" : ["Anovar","Anovar too"],
    "Failed to create group" : "Nun se pue crear el grupu",
    "Creating group…" : "Creando'l grupu…",
    "Create group" : "Crear el grupu",
    "Group name" : "Nome del grupu",
    "Please enter a valid group name" : "Introduz un nome válidu pal grupu",
    "Loading groups…" : "Cargando los grupos…",
    "Could not load app discover section" : "Nun se pudo cargar la seición de descubrimientu d'aplicaciones",
    "Could not render element" : "Nun se pudo dibuxar l'elementu",
    "Loading" : "Cargando",
    "Carousel" : "Carrusel",
    "Previous slide" : "Diapositiva anterior",
    "Next slide" : "Diapositiva siguiente",
    "{index} of {total}" : "{index} de {total}",
    "Daemon" : "Degorriu",
    "Type" : "Tipu",
    "Display Name" : "Nome visible",
    "Learn more" : "Deprendi más",
    "Confirm" : "Confirmar",
    "Cancel" : "Encaboxar",
    "Description" : "Descripción",
    "View in store" : "Ver na tienda",
    "Visit website" : "Visitar el sitiu web",
    "Admin documentation" : "Documentación p'alministradores",
    "Developer documentation" : "Documentación pa desendolcadores",
    "Details" : "Detalles",
    "All" : "Too",
    "No results" : "Nun hai nengún resultáu",
    "Update to {version}" : "Anovar a la versión {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación nun se pue instalar porque nun se cumplen les dependencies siguientes:",
    "Author" : "Autoría",
    "Categories" : "Categories",
    "Resources" : "Recursos",
    "Documentation" : "Documentación",
    "Interact" : "Interactuar",
    "Report a bug" : "Informar d'un fallu",
    "Request feature" : "Pidir una función",
    "Ask questions or discuss" : "Entrugar o discutir",
    "Rate" : "Valorar",
    "Changelog" : "Rexistru de cambeos",
    "Google Chrome for Android" : "Google Chrome p'Android",
    "{productName} iOS app" : "Aplicación de {productName} pa iOS",
    "{productName} Android app" : "Aplicación de {productName} p'Android",
    "{productName} Talk for iOS" : "{productName} Talk pa iOS",
    "{productName} Talk for Android" : "{productName} Talk p'Android",
    "Sync client" : "Sincronizar el veceru",
    "This session" : "Esta sesión",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Nome del preséu",
    "Cancel renaming" : "Anular el cambéu de nome",
    "Save new name" : "Guardar el nome nuevu",
    "Device settings" : "Configuración del preséu",
    "Allow filesystem access" : "Permitir l'accesu al sistema de ficheros",
    "Rename" : "Renomar",
    "Revoke" : "Revocar",
    "Wipe device" : "Borrar el preséu",
    "Device" : "Preséu",
    "Last activity" : "Última actividá",
    "Devices & sessions" : "Preseos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Los veceros que tienen la sesión aniciada na cuenta.",
    "Error while creating device token" : "Hebo error mentanto se creaba'l pase del preséu",
    "App name" : "Nome de l'aplicación",
    "Create new app password" : "Crear una contraseña d'aplicación",
    "App password copied!" : "¡Copióse la contraseña d'aplicación!",
    "Copy app password" : "Copiar la contraseña d'aplicación",
    "Login name copied!" : "¡Copióse'l nome p'aniciar la sesión!",
    "Copy login name" : "Copiar el nome p'aniciar la sesión",
    "Could not copy app password. Please copy it manually." : "Nun se pudo copiar la contraseña d'aplicación. Cópiala manualmente.",
    "Could not copy login name. Please copy it manually." : "Nun se pudo copiar el nome p'aniciar la sesión. Cópialu manualmente.",
    "New app password" : "Contraseña d'aplicación nueva",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Usa les credenciales d'abaxo pa configurar l'aplicación o preséu. Por motivos de seguranza, namás va amosase una vegada.",
    "Login" : "Aniciar la sesión",
    "Password" : "Contraseña",
    "Show QR code for mobile apps" : "Amosar el códigu QR pa les aplicaciones pa móviles",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "La estensión POSIX de PHP ye obligatoria. Mira la {linkstart}documentación de PHP{linkend} pa más información.",
    "Unable to update background job mode" : "Nun ye posible anovar el mou del trabayu en segundu planu",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Pa que'l sirvidor funcione afayadizamente, ye importante configurar correutamente los trabayos en segundu planu. Cron ye la opción aconseyada. Mira la documentación pa consiguir más información.",
    "Last job execution ran {time}. Something seems wrong." : "La última execución del trabayu executó {time}. Paez qu'hai daqué mal.",
    "Last job ran {relativeTime}." : "L'últimu trabayu executó {relativeTime}.",
    "Background job did not run yet!" : "¡El trabayu en segundu planu nun s'executó!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (aconséyase)",
    "Unable to update profile default setting" : "Nun ye posible anovar la opción predeterminada del sirvidor",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new accounts." : "Des/activa'l perfil predetermináu pa les cuentes nueves.",
    "Password confirmation is required" : "Ríquese la contraseña de confirmación",
    "Failed to save setting" : "Nun se pue guardar la opción",
    "Unable to update server side encryption config" : "Nun ye posible anovar la configuración del cifráu del sirvidor",
    "Server-side encryption" : "Cifráu de llau del sirvidor",
    "Enable server-side encryption" : "Activar el cifráu del sirvidor",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nun se cargó nengún módulu de cifráu, activa unu nel menú d'aplicaciones.",
    "Enable encryption" : "Activar el cifráu",
    "Please read carefully before activating server-side encryption:" : "Llei con procuru enantes d'activar el cifráu nel sirvidor:",
    "Please confirm the group removal" : "Confirma'l desaniciu del grupu",
    "Submit" : "Unviar",
    "Rename group" : "Renomar el grupu",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar la contraseña",
    "Please select a valid png or jpg file" : "Seleiciona un ficheru PNG o JPEG válidu",
    "Error setting profile picture" : "Hebo un error al afitar la semeya del perfil",
    "Error cropping profile picture" : "Hebo un error al recortar la semeya del perfil",
    "Error saving profile picture" : "Hebo un error al guardar la semeya del perfil",
    "Error removing profile picture" : "Hebo un error al quitar la semeya del perfil",
    "Upload profile picture" : "Xubir una semeya del perfil",
    "Choose profile picture from Files" : "Escoyer una semeya de Ficheros",
    "Remove profile picture" : "Quitar la semeya del perfil",
    "The file must be a PNG or JPG" : "El ficheru a ser PNG o JPG",
    "Picture provided by original account" : "La cuenta orixinal fornió la imaxe",
    "Set as profile picture" : "Afitar como semeya del perfil",
    "You are a member of the following groups:" : "Yes miembru de los grupos siguientes:",
    "Your full name" : "Nome completu",
    "Remove primary email" : "Quitar la direición de corréu electrónicu",
    "Delete email" : "Desaniciar la direición de corréu electrónicu",
    "This address is not confirmed" : "Esta direición nun ta confirmada",
    "Set as primary email" : "Afitar como direición de corréu electrónicu primaria",
    "Unable to delete primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
    "Unable to update primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
    "Unable to add additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
    "Unable to update additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
    "Unable to delete additional email address" : "Nun ye posible desaniciar la direición de corréu electrónicu adicional",
    "No email address set" : "Nun s'afitó nenguna direición de corréu electrónicu",
    "Unable to update language" : "Nun ye posible anovar la llingua",
    "Languages" : "Llingües",
    "Help translate" : "Ayudar a traducir",
    "No language set" : "Nun s'afitó nenguna llingua",
    "Unable to update locale" : "Nun ye posible anovar la locale",
    "Locales" : "Locales",
    "No locale set" : "Nun s'afitó nenguna locale",
    "Your city" : "Ciudá",
    "Your organisation" : "Organización",
    "Your phone number" : "Númberu de teléfonu",
    "Edit your Profile visibility" : "Editar la visibilidá del perfil",
    "Unable to update profile enabled state" : "Nun ye posible anovar l'estáu d'activación del perfil",
    "Enable profile" : "Activar el perfil",
    "Unable to update visibility of {displayId}" : "Nun ye posible anovar la visibilidá de: {displayId}",
    "Your role" : "El to rol",
    "Your website" : "El to sitiu web",
    "Invalid value" : "El valor ye inválidu",
    "Unable to update {property}" : "Nun ye posible anovar «{property}»",
    "No {property} set" : "Nun s'afitó la propiedá «{property}»",
    "Unable to update federation scope of the primary {property}" : "Nun ye posible anovar l'ámbitu de federación de la propiedá «{property}»",
    "Unable to update federation scope of additional {property}" : "Nun ye posible anovar l'ámbitu de federación de la propiedá adicional «{property}»",
    "Add additional email" : "Direición de corréu electrónicu adicional",
    "Add" : "Amestar",
    "Create" : "Crear",
    "Change" : "Camudar",
    "Delete" : "Desaniciar",
    "Reshare" : "Volver compartir",
    "Default language" : "Llingua predeterminada",
    "Common languages" : "Llingües habituales",
    "Other languages" : "Otres llingües",
    "Password change is disabled because the master key is disabled" : "El cambéu de contraseña ta desactiváu porque la clave maestra ta desactivada",
    "No accounts" : "Nun hai nenguna cuenta",
    "Loading accounts …" : "Cargando les cuentes…",
    "Manager" : "Xestor",
    "Set line manager" : "Afitar el xestor de llinies",
    "New account" : "Cuenta nueva",
    "Display name" : "Nome visible",
    "Password (required)" : "Contraseña (obligatoria)",
    "Email (required)" : "Corréu electrónicu (obligatoriu)",
    "Email" : "Corréu electrónicu",
    "Quota" : "Cuota",
    "Language" : "Llingua",
    "Set default language" : "Predeterminar la llingua",
    "Total rows summary" : "Resume total de fieleres",
    "Scroll to load more rows" : "Desplaza pa cargar fileres",
    "Avatar" : "Avatar",
    "Storage location" : "Llocalización del almacenamientu",
    "Last login" : "Últimu aniciu de la sesión",
    "{size} used" : "{size} n'usu",
    "Delete account" : "Dersaniciar la cuenta",
    "Disconnect all devices and delete local data" : "Desconectar tolos preseos y desaniciar los datos llocales",
    "Disable account" : "Desactivar la cuenta",
    "Enable account" : "Activar la cuenta",
    "Resend welcome email" : "Volver unviar el mensaxe d'acoyida",
    "Remote wipe of devices" : "Borráu remotu de los preseos",
    "Failed to update line manager" : "Nun se pue anovar el xestor de llinies",
    "Account deletion" : "Desaniciu de la cuenta",
    "Delete {userid}'s account" : "Desaniciar la cuenta de: {userid}",
    "Display name was successfully changed" : "El nome visible camudó correutamente",
    "Password was successfully changed" : "La contraseña camudó correutamente",
    "Email was successfully changed" : "La direición de corréu electrónicu camudó correutamente",
    "Welcome mail sent!" : "¡Unvióse'l mensaxe d'acoyida!",
    "Loading account …" : "Cargando la cuenta…",
    "Change display name" : "Camudar el nome visible",
    "Set new password" : "Afitar una contraseña nueva",
    "You do not have permissions to see the details of this account" : "Nun tienes permisu pa ver los detalles d'esta cuenta",
    "Set new email address" : "Afitar una direición de corréu electrónicu nueva",
    "Add account to group" : "Amestar la cuenta al grupu",
    "Set the language" : "Afitar la llingua",
    "Done" : "Fecho",
    "Edit" : "Editar",
    "Account management settings" : "Configuración de la xestión de cuentes",
    "Visibility" : "Visibilidá",
    "Show language" : "Amosar la llingua",
    "Show last login" : "Amosar l'últimu aniciu de la sesión",
    "Sorting" : "Orde",
    "By member count" : "Pol númberu de miembros",
    "By name" : "Pol nome",
    "Send email" : "Unviar un corréu electrónicu",
    "Send welcome email to new accounts" : "Unviar el mensaxe d'acoyida a les cuentes nueves",
    "Defaults" : "Valores predeterminaos",
    "Default quota" : "Cuota predeterminada",
    "Server error while trying to complete WebAuthn device registration" : "Error del sirvidor mentanto se completaba'l rexistru del preséu WebAuthn.",
    "Passwordless authentication requires a secure connection." : "L'autenticación ensin contraseña rique una conexón segura.",
    "Add WebAuthn device" : "Amestar preséu WebAuthn",
    "Please authorize your WebAuthn device." : "Autoriza'l preséu WebAuthn.",
    "Adding your device …" : "Amestando'l preséu…",
    "Unnamed device" : "Preséu ensin nome",
    "Passwordless Authentication" : "Autenticación ensin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura una cuenta pa l'autenticación ensin contraseña siguiendo l'estándar FIDO2.",
    "No devices configured." : "Nun se configuró nengún preséu.",
    "The following devices are configured for your account:" : "Configuráronse los preseos siguientes pa la cuenta:",
    "Your browser does not support WebAuthn." : "El restolador nun ye compatible con WebAuthn.",
    "You need to enable the File sharing App." : "Tienes d'activar l'aplicación de compartir ficheros.",
    "App Store" : "Tienda d'aplicaciones",
    "Loading app list" : "Cargando la llista d'aplicaciones",
    "Loading categories" : "Cargando les categoríes",
    "Developer documentation ↗" : "Documentación pa desendolcadores ↗",
    "Version {version}, {license}-licensed" : "Versión {version}, con llicencia {license}",
    "Admins" : "Alministradores",
    "Account group: {group}" : "Grupu de cuentes: {group}",
    "Account management" : "Xestión de cuentes",
    "Sending…" : "Unviando…",
    "Email sent" : "Unvióse'l corréu electrónicu",
    "Location" : "Llocalización",
    "Profile picture" : "Semeya del perfil",
    "About" : "Tocante a",
    "Full name" : "Nome completu",
    "Additional email" : "Direición de corréu electrónicu adicional",
    "Fediverse (e.g. Mastodon)" : "Fediversu",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Phone number" : "Númberu de teléfonu",
    "Role" : "Rol",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "Website" : "Sitiu web",
    "Profile visibility" : "Visibilidá del perfil",
    "Locale" : "Locale",
    "Discover" : "Descubrir",
    "Your apps" : "Les to aplicaciones",
    "Active apps" : "Aplicaciones actives",
    "Disabled apps" : "Aplicaciones desactivaes",
    "Updates" : "Anovamientos",
    "Featured apps" : "Aplicaciones destacaes",
    "Supported apps" : "Aplicaciones compatibles",
    "Show to everyone" : "Amosar a tol mundu",
    "Show to logged in accounts only" : "Amosar namás a les cuentes cola sesión aniciada",
    "Hide" : "Esconder",
    "Download and enable" : "Baxar y activar",
    "Disable" : "Desactivar",
    "Allow untested app" : "Permitir l'aplicación ensin probar",
    "Unknown" : "Desconocí­u",
    "Never" : "Enxamás",
    "An error occurred during the request. Unable to proceed." : "Prodúxose un error demientres la solicitú. Nun ye posible siguir.",
    "The app has been enabled but needs to be updated." : "Activóse l'aplicación mas tien que s'anovar.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: nun se pue activar esta aplicación porque fai que'l sirvidor seya inestable",
    "Do you really want to wipe your data from this device?" : "¿De xuru que quies borrar los datos d'esti preséu?",
    "Confirm wipe" : "Confirmar el borráu",
    "Could not delete the app token" : "Nun se pudo desaniciar el pase de l'aplicación",
    "Error while wiping the device with the token" : "Hebo un error mentanto se llimpiaba'l preséu col pase",
    "Error while updating device token name" : "Hebo un error mentanto s'anovaba'l nome'l pase'l preséu",
    "Error while updating device token scope" : "Hebo un error mentanto s'anovaba l'ámbitu'l pase'l preséu",
    "Could not set group sorting" : "Nun se pudo afitar l'orde de los grupos",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ficiéronse milenta solicitúes dende la to rede. Volvi tentalo dempués o ponte en contautu cola alministración si esti mensaxe ye un error.",
    "Error" : "Error",
    "Account documentation" : "Documentación de la cuenta",
    "Administration documentation" : "Documentación de l'alministración",
    "Forum" : "Foru",
    "Nextcloud help & privacy resources" : "Ayuda de Nextcloud y recursos de privacidá",
    "General documentation" : "Documentación xeneral",
    "Legal notice" : "Avisu llegal",
    "Privacy policy" : "Política de privacidá",
    "None/STARTTLS" : "Nada/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Abrir la documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ye importante configurar esti sirvidor pa que seya a unviar correos electrónicos de, por exemplu, avisos o solicitúes pa reafitar contraseñes",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "De la direición",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Authentication" : "Autenticación",
    "Authentication required" : "L'autenticación ye obligatoria",
    "SMTP Password" : "Contraseña de SMTP",
    "Save" : "Guardar",
    "Security & setup warnings" : "Alvertencies de seguranza y de configuración",
    "There are some errors regarding your setup." : "Hai dalgunos errores en rellación a la configuración.",
    "There are some warnings regarding your setup." : "Hai dalgunes alvertencies en rellación a la configuración.",
    "Reasons to use Nextcloud in your organization" : "Razones pa usar Nextcloud na to organzación",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desendolcáu pola {communityopen}comunidá de Nextcloud{linkclose}, el {githubopen}códigu fonte{linkclose} llicénciase baxo l'{licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da un préstame a la nuesa páxina de Facebook",
    "Follow us on Mastodon" : "Síguinos en Mastodon",
    "Check out our blog" : "Revisa'l nuesu blogue",
    "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
    "Logged in account must be a subadmin" : "La cuenta qu'anició la sesión ha ser un soalministrador",
    "File locking" : "Bloquéu de ficheros",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "El bloquéu de ficheros transaicional ta desactiváu y esto quiciabes produza problemes con condiciones de carrera. Activa «filelocking.enabled» nel ficheru config.php pa evitar estos problemes.",
    "The PHP memory limit is below the recommended value of %s." : "La llende de memoria de PHP ye inferior al valor aconseyáu de %s.",
    "Your biography" : "Biografía",
    "You are using <strong>{usage}</strong>" : "Tas usando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Tas usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
},
"nplurals=2; plural=(n != 1);");
